@@ -4,6 +4,14 @@ Puppet::Type.newtype(:tempest_neutron_net_id_setter) do
 
   newparam(:name, :namevar => true) do
     desc 'The name of the setting to update.'
+    munge do |value|
+      if value.include? '/'
+        value
+      else
+        # This is to keep the backword compatibility
+        "network/#{value}"
+      end
+    end
   end
 
   newparam(:tempest_conf_path) do
@@ -14,6 +22,10 @@ Puppet::Type.newtype(:tempest_neutron_net_id_setter) do
     desc 'The name of the neutron network.'
   end
 
+  autorequire(:neutron_network) do
+    [self[:network_name]] if self[:network_name]
+  end
+
   autorequire(:package) do
     ['python-openstackclient', 'python3-openstackclient']
   end
