@@ -1,6 +1,14 @@
 require 'spec_helper'
 
 describe 'tempest::magnum' do
+  let :pre_condition do
+    "
+    class { 'tempest':
+      configure_networks => false,
+      configure_images   => false
+    }"
+  end
+
   let :params do
     { :nic_id => 'b2e6021a-4956-4a1f-8329-790b9add05a9', }
   end
@@ -18,11 +26,12 @@ describe 'tempest::magnum' do
 
         is_expected.to contain_tempest_config('magnum/image_id').with_value('fedora-atomic-latest')
         is_expected.to contain_tempest_config('magnum/nic_id').with_value('b2e6021a-4956-4a1f-8329-790b9add05a9')
-        is_expected.to contain_tempest_config('magnum/keypair_id').with_value('default')
+        is_expected.to contain_tempest_config('magnum/keypair_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_tempest_config('magnum/flavor_id').with_value('s1.magnum')
         is_expected.to contain_tempest_config('magnum/master_flavor_id').with_value('m1.magnum')
-        is_expected.to contain_tempest_config('magnum/copy_logs').with_value('true')
-        is_expected.to contain_tempest_config('magnum/dns_nameserver').with_value('8.8.8.8')
+        is_expected.to contain_tempest_config('magnum/magnum_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_tempest_config('magnum/copy_logs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_tempest_config('magnum/dns_nameserver').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -34,7 +43,7 @@ describe 'tempest::magnum' do
           :provision_flavors => false,
           :flavor_id         => 's1.tempest',
           :master_flavor_id  => 'm1.tempest',
-          :keypair_id        => 'magnum',
+          :keypair_name      => 'magnum',
           :provision_keypair => false,
           :magnum_url        => 'http://magnum/',
           :copy_logs         => false,
@@ -45,7 +54,7 @@ describe 'tempest::magnum' do
       it 'configures tempest for magnum' do
         is_expected.to contain_tempest_config('magnum/image_id').with_value('coreos')
         is_expected.to contain_tempest_config('magnum/nic_id').with_value('b2e6021a-4956-4a1f-8329-790b9add05a9')
-        is_expected.to contain_tempest_config('magnum/keypair_id').with_value('magnum')
+        is_expected.to contain_tempest_config('magnum/keypair_name').with_value('magnum')
         is_expected.to contain_tempest_config('magnum/flavor_id').with_value('s1.tempest')
         is_expected.to contain_tempest_config('magnum/master_flavor_id').with_value('m1.tempest')
         is_expected.to contain_tempest_config('magnum/magnum_url').with_value('http://magnum/')
